package
Version:
v0.0.0-...-5ed2d9f
Opens a new window with list of versions in this module.
Published: Jul 23, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Do(ctx context.Context, content interface{}, opType mgo常量.OpType, opts ...interface{}) error
始终调用每个注册
文档始终是操作文档
md5:f300f2035d7e8114
func Register(回调函数 callback)
Register 将回调函数注册到中间件中 md5:23bc8366f03c6dbb
Source Files
¶
Click to show internal directories.
Click to hide internal directories.